# YouRAG

Your tool for RAG on any source of knowledge.

## Install

`uv add yourag`

## How to use 

```bash
yourag ingest --video-url https://youtube.com/... --name docker-video
yourag query-text --name docker-video -- "How do I install this?"
```
